Class: Aws::Finspace::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Finspace::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-finspace/client.rb,
sig/client.rbs
Overview
An API client for Finspace. To construct a client, you need to configure a :region and :credentials.
client = Aws::Finspace::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateEnvironmentResponseSuccess, _CreateKxChangesetResponseSuccess, _CreateKxClusterResponseSuccess, _CreateKxDatabaseResponseSuccess, _CreateKxDataviewResponseSuccess, _CreateKxEnvironmentResponseSuccess, _CreateKxScalingGroupResponseSuccess, _CreateKxUserResponseSuccess, _CreateKxVolumeResponseSuccess, _DeleteEnvironmentResponseSuccess, _DeleteKxClusterNodeResponseSuccess, _DeleteKxClusterResponseSuccess, _DeleteKxDatabaseResponseSuccess, _DeleteKxDataviewResponseSuccess, _DeleteKxEnvironmentResponseSuccess, _DeleteKxScalingGroupResponseSuccess, _DeleteKxUserResponseSuccess, _DeleteKxVolumeResponseSuccess, _GetEnvironmentResponseSuccess, _GetKxChangesetResponseSuccess, _GetKxClusterResponseSuccess, _GetKxConnectionStringResponseSuccess, _GetKxDatabaseResponseSuccess, _GetKxDataviewResponseSuccess, _GetKxEnvironmentResponseSuccess, _GetKxScalingGroupResponseSuccess, _GetKxUserResponseSuccess, _GetKxVolumeResponseSuccess, _ListEnvironmentsResponseSuccess, _ListKxChangesetsResponseSuccess, _ListKxClusterNodesResponseSuccess, _ListKxClustersResponseSuccess, _ListKxDatabasesResponseSuccess, _ListKxDataviewsResponseSuccess, _ListKxEnvironmentsResponseSuccess, _ListKxScalingGroupsResponseSuccess, _ListKxUsersResponseSuccess, _ListKxVolumesResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateEnvironmentResponseSuccess, _UpdateKxClusterCodeConfigurationResponseSuccess, _UpdateKxClusterDatabasesResponseSuccess, _UpdateKxDatabaseResponseSuccess, _UpdateKxDataviewResponseSuccess, _UpdateKxEnvironmentNetworkResponseSuccess, _UpdateKxEnvironmentResponseSuccess, _UpdateKxUserResponseSuccess, _UpdateKxVolumeResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Create a new FinSpace environment.
-
#create_kx_changeset(params = {}) ⇒ Types::CreateKxChangesetResponse
Creates a changeset for a kdb database.
-
#create_kx_cluster(params = {}) ⇒ Types::CreateKxClusterResponse
Creates a new kdb cluster.
-
#create_kx_database(params = {}) ⇒ Types::CreateKxDatabaseResponse
Creates a new kdb database in the environment.
-
#create_kx_dataview(params = {}) ⇒ Types::CreateKxDataviewResponse
Creates a snapshot of kdb database with tiered storage capabilities and a pre-warmed cache, ready for mounting on kdb clusters.
-
#create_kx_environment(params = {}) ⇒ Types::CreateKxEnvironmentResponse
Creates a managed kdb environment for the account.
-
#create_kx_scaling_group(params = {}) ⇒ Types::CreateKxScalingGroupResponse
Creates a new scaling group.
-
#create_kx_user(params = {}) ⇒ Types::CreateKxUserResponse
Creates a user in FinSpace kdb environment with an associated IAM role.
-
#create_kx_volume(params = {}) ⇒ Types::CreateKxVolumeResponse
Creates a new volume with a specific amount of throughput and storage capacity.
-
#delete_environment(params = {}) ⇒ Struct
Delete an FinSpace environment.
-
#delete_kx_cluster(params = {}) ⇒ Struct
Deletes a kdb cluster.
-
#delete_kx_cluster_node(params = {}) ⇒ Struct
Deletes the specified nodes from a cluster.
-
#delete_kx_database(params = {}) ⇒ Struct
Deletes the specified database and all of its associated data.
-
#delete_kx_dataview(params = {}) ⇒ Struct
Deletes the specified dataview.
-
#delete_kx_environment(params = {}) ⇒ Struct
Deletes the kdb environment.
-
#delete_kx_scaling_group(params = {}) ⇒ Struct
Deletes the specified scaling group.
-
#delete_kx_user(params = {}) ⇒ Struct
Deletes a user in the specified kdb environment.
-
#delete_kx_volume(params = {}) ⇒ Struct
Deletes a volume.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns the FinSpace environment object.
-
#get_kx_changeset(params = {}) ⇒ Types::GetKxChangesetResponse
Returns information about a kdb changeset.
-
#get_kx_cluster(params = {}) ⇒ Types::GetKxClusterResponse
Retrieves information about a kdb cluster.
-
#get_kx_connection_string(params = {}) ⇒ Types::GetKxConnectionStringResponse
Retrieves a connection string for a user to connect to a kdb cluster.
-
#get_kx_database(params = {}) ⇒ Types::GetKxDatabaseResponse
Returns database information for the specified environment ID.
-
#get_kx_dataview(params = {}) ⇒ Types::GetKxDataviewResponse
Retrieves details of the dataview.
-
#get_kx_environment(params = {}) ⇒ Types::GetKxEnvironmentResponse
Retrieves all the information for the specified kdb environment.
-
#get_kx_scaling_group(params = {}) ⇒ Types::GetKxScalingGroupResponse
Retrieves details of a scaling group.
-
#get_kx_user(params = {}) ⇒ Types::GetKxUserResponse
Retrieves information about the specified kdb user.
-
#get_kx_volume(params = {}) ⇒ Types::GetKxVolumeResponse
Retrieves the information about the volume.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
A list of all of your FinSpace environments.
-
#list_kx_changesets(params = {}) ⇒ Types::ListKxChangesetsResponse
Returns a list of all the changesets for a database.
-
#list_kx_cluster_nodes(params = {}) ⇒ Types::ListKxClusterNodesResponse
Lists all the nodes in a kdb cluster.
-
#list_kx_clusters(params = {}) ⇒ Types::ListKxClustersResponse
Returns a list of clusters.
-
#list_kx_databases(params = {}) ⇒ Types::ListKxDatabasesResponse
Returns a list of all the databases in the kdb environment.
-
#list_kx_dataviews(params = {}) ⇒ Types::ListKxDataviewsResponse
Returns a list of all the dataviews in the database.
-
#list_kx_environments(params = {}) ⇒ Types::ListKxEnvironmentsResponse
Returns a list of kdb environments created in an account.
-
#list_kx_scaling_groups(params = {}) ⇒ Types::ListKxScalingGroupsResponse
Returns a list of scaling groups in a kdb environment.
-
#list_kx_users(params = {}) ⇒ Types::ListKxUsersResponse
Lists all the users in a kdb environment.
-
#list_kx_volumes(params = {}) ⇒ Types::ListKxVolumesResponse
Lists all the volumes in a kdb environment.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of all tags for a resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a FinSpace resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a FinSpace resource.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Update your FinSpace environment.
-
#update_kx_cluster_code_configuration(params = {}) ⇒ Struct
Allows you to update code configuration on a running cluster.
-
#update_kx_cluster_databases(params = {}) ⇒ Struct
Updates the databases mounted on a kdb cluster, which includes the
changesetIdand all the dbPaths to be cached. -
#update_kx_database(params = {}) ⇒ Types::UpdateKxDatabaseResponse
Updates information for the given kdb database.
-
#update_kx_dataview(params = {}) ⇒ Types::UpdateKxDataviewResponse
Updates the specified dataview.
-
#update_kx_environment(params = {}) ⇒ Types::UpdateKxEnvironmentResponse
Updates information for the given kdb environment.
-
#update_kx_environment_network(params = {}) ⇒ Types::UpdateKxEnvironmentNetworkResponse
Updates environment network to connect to your internal network by using a transit gateway.
-
#update_kx_user(params = {}) ⇒ Types::UpdateKxUserResponse
Updates the user details.
-
#update_kx_volume(params = {}) ⇒ Types::UpdateKxVolumeResponse
Updates the throughput or capacity of a volume.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-finspace/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3838 3839 3840 |
# File 'lib/aws-sdk-finspace/client.rb', line 3838 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3841 3842 3843 |
# File 'lib/aws-sdk-finspace/client.rb', line 3841 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3811 3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 3827 |
# File 'lib/aws-sdk-finspace/client.rb', line 3811 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Finspace') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-finspace' context[:gem_version] = '1.72.0' Seahorse::Client::Request.new(handlers, context) end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Create a new FinSpace environment.
88 |
# File 'sig/client.rbs', line 88 def create_environment: ( |
#create_kx_changeset(params = {}) ⇒ Types::CreateKxChangesetResponse
Creates a changeset for a kdb database. A changeset allows you to add and delete existing files by using an ordered list of change requests.
116 |
# File 'sig/client.rbs', line 116 def create_kx_changeset: ( |
#create_kx_cluster(params = {}) ⇒ Types::CreateKxClusterResponse
Creates a new kdb cluster.
158 |
# File 'sig/client.rbs', line 158 def create_kx_cluster: ( |
#create_kx_database(params = {}) ⇒ Types::CreateKxDatabaseResponse
Creates a new kdb database in the environment.
236 |
# File 'sig/client.rbs', line 236 def create_kx_database: ( |
#create_kx_dataview(params = {}) ⇒ Types::CreateKxDataviewResponse
Creates a snapshot of kdb database with tiered storage capabilities and a pre-warmed cache, ready for mounting on kdb clusters. Dataviews are only available for clusters running on a scaling group. They are not supported on dedicated clusters.
262 |
# File 'sig/client.rbs', line 262 def create_kx_dataview: ( |
#create_kx_environment(params = {}) ⇒ Types::CreateKxEnvironmentResponse
Creates a managed kdb environment for the account.
295 |
# File 'sig/client.rbs', line 295 def create_kx_environment: ( |
#create_kx_scaling_group(params = {}) ⇒ Types::CreateKxScalingGroupResponse
Creates a new scaling group.
315 |
# File 'sig/client.rbs', line 315 def create_kx_scaling_group: ( |
#create_kx_user(params = {}) ⇒ Types::CreateKxUserResponse
Creates a user in FinSpace kdb environment with an associated IAM role.
333 |
# File 'sig/client.rbs', line 333 def create_kx_user: ( |
#create_kx_volume(params = {}) ⇒ Types::CreateKxVolumeResponse
Creates a new volume with a specific amount of throughput and storage capacity.
357 |
# File 'sig/client.rbs', line 357 def create_kx_volume: ( |
#delete_environment(params = {}) ⇒ Struct
Delete an FinSpace environment.
377 |
# File 'sig/client.rbs', line 377 def delete_environment: ( |
#delete_kx_cluster(params = {}) ⇒ Struct
Deletes a kdb cluster.
386 |
# File 'sig/client.rbs', line 386 def delete_kx_cluster: ( |
#delete_kx_cluster_node(params = {}) ⇒ Struct
Deletes the specified nodes from a cluster.
397 |
# File 'sig/client.rbs', line 397 def delete_kx_cluster_node: ( |
#delete_kx_database(params = {}) ⇒ Struct
Deletes the specified database and all of its associated data. This action is irreversible. You must copy any data out of the database before deleting it if the data is to be retained.
408 |
# File 'sig/client.rbs', line 408 def delete_kx_database: ( |
#delete_kx_dataview(params = {}) ⇒ Struct
Deletes the specified dataview. Before deleting a dataview, make sure that it is not in use by any cluster.
419 |
# File 'sig/client.rbs', line 419 def delete_kx_dataview: ( |
#delete_kx_environment(params = {}) ⇒ Struct
Deletes the kdb environment. This action is irreversible. Deleting a kdb environment will remove all the associated data and any services running in it.
431 |
# File 'sig/client.rbs', line 431 def delete_kx_environment: ( |
#delete_kx_scaling_group(params = {}) ⇒ Struct
Deletes the specified scaling group. This action is irreversible. You cannot delete a scaling group until all the clusters running on it have been deleted.
441 |
# File 'sig/client.rbs', line 441 def delete_kx_scaling_group: ( |
#delete_kx_user(params = {}) ⇒ Struct
Deletes a user in the specified kdb environment.
452 |
# File 'sig/client.rbs', line 452 def delete_kx_user: ( |
#delete_kx_volume(params = {}) ⇒ Struct
Deletes a volume. You can only delete a volume if it's not attached to a cluster or a dataview. When a volume is deleted, any data on the volume is lost. This action is irreversible.
463 |
# File 'sig/client.rbs', line 463 def delete_kx_volume: ( |
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns the FinSpace environment object.
475 |
# File 'sig/client.rbs', line 475 def get_environment: ( |
#get_kx_changeset(params = {}) ⇒ Types::GetKxChangesetResponse
Returns information about a kdb changeset.
493 |
# File 'sig/client.rbs', line 493 def get_kx_changeset: ( |
#get_kx_cluster(params = {}) ⇒ Types::GetKxClusterResponse
Retrieves information about a kdb cluster.
527 |
# File 'sig/client.rbs', line 527 def get_kx_cluster: ( |
#get_kx_connection_string(params = {}) ⇒ Types::GetKxConnectionStringResponse
Retrieves a connection string for a user to connect to a kdb cluster. You must call this API using the same role that you have defined while creating a user.
538 |
# File 'sig/client.rbs', line 538 def get_kx_connection_string: ( |
#get_kx_database(params = {}) ⇒ Types::GetKxDatabaseResponse
Returns database information for the specified environment ID.
559 |
# File 'sig/client.rbs', line 559 def get_kx_database: ( |
#get_kx_dataview(params = {}) ⇒ Types::GetKxDataviewResponse
Retrieves details of the dataview.
584 |
# File 'sig/client.rbs', line 584 def get_kx_dataview: ( |
#get_kx_environment(params = {}) ⇒ Types::GetKxEnvironmentResponse
Retrieves all the information for the specified kdb environment.
612 |
# File 'sig/client.rbs', line 612 def get_kx_environment: ( |
#get_kx_scaling_group(params = {}) ⇒ Types::GetKxScalingGroupResponse
Retrieves details of a scaling group.
630 |
# File 'sig/client.rbs', line 630 def get_kx_scaling_group: ( |
#get_kx_user(params = {}) ⇒ Types::GetKxUserResponse
Retrieves information about the specified kdb user.
644 |
# File 'sig/client.rbs', line 644 def get_kx_user: ( |
#get_kx_volume(params = {}) ⇒ Types::GetKxVolumeResponse
Retrieves the information about the volume.
667 |
# File 'sig/client.rbs', line 667 def get_kx_volume: ( |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
A list of all of your FinSpace environments.
679 |
# File 'sig/client.rbs', line 679 def list_environments: ( |
#list_kx_changesets(params = {}) ⇒ Types::ListKxChangesetsResponse
Returns a list of all the changesets for a database.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
691 |
# File 'sig/client.rbs', line 691 def list_kx_changesets: ( |
#list_kx_cluster_nodes(params = {}) ⇒ Types::ListKxClusterNodesResponse
Lists all the nodes in a kdb cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
705 |
# File 'sig/client.rbs', line 705 def list_kx_cluster_nodes: ( |
#list_kx_clusters(params = {}) ⇒ Types::ListKxClustersResponse
Returns a list of clusters.
719 |
# File 'sig/client.rbs', line 719 def list_kx_clusters: ( |
#list_kx_databases(params = {}) ⇒ Types::ListKxDatabasesResponse
Returns a list of all the databases in the kdb environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
733 |
# File 'sig/client.rbs', line 733 def list_kx_databases: ( |
#list_kx_dataviews(params = {}) ⇒ Types::ListKxDataviewsResponse
Returns a list of all the dataviews in the database.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
746 |
# File 'sig/client.rbs', line 746 def list_kx_dataviews: ( |
#list_kx_environments(params = {}) ⇒ Types::ListKxEnvironmentsResponse
Returns a list of kdb environments created in an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
760 |
# File 'sig/client.rbs', line 760 def list_kx_environments: ( |
#list_kx_scaling_groups(params = {}) ⇒ Types::ListKxScalingGroupsResponse
Returns a list of scaling groups in a kdb environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
772 |
# File 'sig/client.rbs', line 772 def list_kx_scaling_groups: ( |
#list_kx_users(params = {}) ⇒ Types::ListKxUsersResponse
Lists all the users in a kdb environment.
785 |
# File 'sig/client.rbs', line 785 def list_kx_users: ( |
#list_kx_volumes(params = {}) ⇒ Types::ListKxVolumesResponse
Lists all the volumes in a kdb environment.
798 |
# File 'sig/client.rbs', line 798 def list_kx_volumes: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list of all tags for a resource.
811 |
# File 'sig/client.rbs', line 811 def list_tags_for_resource: ( |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a FinSpace resource.
820 |
# File 'sig/client.rbs', line 820 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a FinSpace resource.
830 |
# File 'sig/client.rbs', line 830 def untag_resource: ( |
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Update your FinSpace environment.
841 |
# File 'sig/client.rbs', line 841 def update_environment: ( |
#update_kx_cluster_code_configuration(params = {}) ⇒ Struct
Allows you to update code configuration on a running cluster. By using this API you can update the code, the initialization script path, and the command line arguments for a specific cluster. The configuration that you want to update will override any existing configurations on the cluster.
854 |
# File 'sig/client.rbs', line 854 def update_kx_cluster_code_configuration: ( |
#update_kx_cluster_databases(params = {}) ⇒ Struct
Updates the databases mounted on a kdb cluster, which includes the
changesetId and all the dbPaths to be cached. This API does not
allow you to change a database name or add a database if you created a
cluster without one.
Using this API you can point a cluster to a different changeset and modify a list of partitions being cached.
880 |
# File 'sig/client.rbs', line 880 def update_kx_cluster_databases: ( |
#update_kx_database(params = {}) ⇒ Types::UpdateKxDatabaseResponse
Updates information for the given kdb database.
901 |
# File 'sig/client.rbs', line 901 def update_kx_database: ( |
#update_kx_dataview(params = {}) ⇒ Types::UpdateKxDataviewResponse
Updates the specified dataview. The dataviews get automatically updated when any new changesets are ingested. Each update of the dataview creates a new version, including changeset details and cache configurations
927 |
# File 'sig/client.rbs', line 927 def update_kx_dataview: ( |
#update_kx_environment(params = {}) ⇒ Types::UpdateKxEnvironmentResponse
Updates information for the given kdb environment.
964 |
# File 'sig/client.rbs', line 964 def update_kx_environment: ( |
#update_kx_environment_network(params = {}) ⇒ Types::UpdateKxEnvironmentNetworkResponse
Updates environment network to connect to your internal network by using a transit gateway. This API supports request to create a transit gateway attachment from FinSpace VPC to your transit gateway ID and create a custom Route-53 outbound resolvers.
Once you send a request to update a network, you cannot change it again. Network update might require termination of any clusters that are running in the existing network.
992 |
# File 'sig/client.rbs', line 992 def update_kx_environment_network: ( |
#update_kx_user(params = {}) ⇒ Types::UpdateKxUserResponse
Updates the user details. You can only update the IAM role associated with a user.
1032 |
# File 'sig/client.rbs', line 1032 def update_kx_user: ( |
#update_kx_volume(params = {}) ⇒ Types::UpdateKxVolumeResponse
Updates the throughput or capacity of a volume. During the update process, the filesystem might be unavailable for a few minutes. You can retry any operations after the update is complete.
1057 |
# File 'sig/client.rbs', line 1057 def update_kx_volume: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3831 3832 3833 |
# File 'lib/aws-sdk-finspace/client.rb', line 3831 def waiter_names [] end |