Class: Aws::Finspace::Types::CodeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-finspace/types.rb

Overview

The structure of the customer code available within the running cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_bucketString

A unique name for the S3 bucket.



173
174
175
176
177
178
179
# File 'lib/aws-sdk-finspace/types.rb', line 173

class CodeConfiguration < Struct.new(
  :s3_bucket,
  :s3_key,
  :s3_object_version)
  SENSITIVE = []
  include Aws::Structure
end

#s3_keyString

The full S3 path (excluding bucket) to the .zip file. This file contains the code that is loaded onto the cluster when it’s started.



173
174
175
176
177
178
179
# File 'lib/aws-sdk-finspace/types.rb', line 173

class CodeConfiguration < Struct.new(
  :s3_bucket,
  :s3_key,
  :s3_object_version)
  SENSITIVE = []
  include Aws::Structure
end

#s3_object_versionString

The version of an S3 object.



173
174
175
176
177
178
179
# File 'lib/aws-sdk-finspace/types.rb', line 173

class CodeConfiguration < Struct.new(
  :s3_bucket,
  :s3_key,
  :s3_object_version)
  SENSITIVE = []
  include Aws::Structure
end