Class: Aws::Finspace::Types::UpdateKxEnvironmentNetworkResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-finspace/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone_idsArray<String>

The identifier of the availability zones where subnets for the environment are created.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The unique identifier of the AWS account that is used to create the kdb environment.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timestampTime

The timestamp at which the kdb environment was created in FinSpace.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#custom_dns_configurationArray<Types::CustomDNSServer>

A list of DNS server name and server IP. This is used to set up Route-53 outbound resolvers.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#dedicated_service_account_idString

A unique identifier for the AWS environment infrastructure account.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the environment.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#dns_statusString

The status of DNS configuration.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#environment_arnString

The ARN identifier of the environment.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

A unique identifier for the kdb environment.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

Specifies the error message that appears if a flow fails.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The KMS key ID to encrypt your data in the FinSpace environment.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the kdb environment.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the kdb environment.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#tgw_statusString

The status of the network configuration.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_configurationTypes::TransitGatewayConfiguration

The structure of the transit gateway and network configuration that is used to connect the kdb environment to an internal network.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end

#update_timestampTime

The timestamp at which the kdb environment was updated.

Returns:



5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/aws-sdk-finspace/types.rb', line 5232

class UpdateKxEnvironmentNetworkResponse < Struct.new(
  :name,
  :environment_id,
  :aws_account_id,
  :status,
  :tgw_status,
  :dns_status,
  :error_message,
  :description,
  :environment_arn,
  :kms_key_id,
  :dedicated_service_account_id,
  :transit_gateway_configuration,
  :custom_dns_configuration,
  :creation_timestamp,
  :update_timestamp,
  :availability_zone_ids)
  SENSITIVE = []
  include Aws::Structure
end